@@ -216,9 +216,9 @@ class Postgres_Handler:
         } 
         
     #Method to update a SQL row
-    def update_record(self, kwargs):
+    def update_record(self, **kwargs):
         values_dict = {}
-        id_key = 'id'
+        id_key = 'Id'
         clause_section = ''
         
          #checks for the table name in args
@@ -232,7 +232,7 @@ class Postgres_Handler:
         values_dict[self.table_name_key] = table_name
         
         for key, value in kwargs.items():
-            if key.lower() == "id" or key.lower() == table_name: continue
+            if key.lower() == id_key.lower() or key.lower() == table_name: continue
             
             clause_section = f' "{key}" = %({key})s AND '
             values_dict[key] = value
@@ -242,7 +242,7 @@ class Postgres_Handler:
         if id_key not in kwargs: assert("Error: ID of record required for an update!")
         
         query_string += f' WHERE "ID"=(id)s'
-        values_dict['id'] = kwargs['id']
+        values_dict[id_key] = kwargs[id_key]
         
         sql_query = sql.SQL(query_string).format(sql.Identifier(table_name = kwargs[self.table_name_key]))
         
